@@ -1,8 +1,7 @@
+from django_cassandra.common.messages import Messages
 from rest_framework.pagination import PageNumberPagination
 from rest_framework.response import Response
 
-from src.django_cassandra.common.messages import Messages
-
 
 class CustomPagination(PageNumberPagination):
     def get_paginated_response(self, data):
