@@ -1,4 +1,4 @@
-from src.django_cassandra.common.messages import Messages
+from django_cassandra.common.messages import Messages
 
 
 def response(data=[], message=Messages.SUCCESSFUL_MESSAGE, status=True):
