@@ -1,3 +1,5 @@
+from django.conf import settings
+from drf_yasg.generators import OpenAPISchemaGenerator
 from rest_framework import serializers
 
 
@@ -5,6 +7,17 @@ class Enums:
     LIST_STATUS = ['ACTIVO', 'INACTIVO']
     ACTIVO = 'ACTIVO'
     INACTIVO = 'INACTIVO'
+    SALE_ABIERTA = 'ABIERTA'
+    SALE_ANULADA = 'ANULADA'
+    SALE_CERRADA = 'CERRADA'
+    LIST_SALE_STATUS = [SALE_ABIERTA, SALE_ANULADA, SALE_CERRADA]
+
+
+class Constants:
+    FORMAT_DATE_TIME = '%Y-%m-%d %H:%M:%S'
+    FORMAT_DATE = '%Y-%m-%d'
+    FORMAT_TIME = '%H:%M:%S'
+    FORMAT_DATE_TIME_TIMEZONE = '%Y-%m-%dT%H:%M:%S.%fZ'
 
 
 class DynamicFieldsSerializer(serializers.ModelSerializer):
@@ -34,3 +47,12 @@ class DynamicFieldsSerializer(serializers.ModelSerializer):
                         self.fields.pop(field_name)
             else:
                 self.fields.pop(notfields)
+
+
+class CustomOpenAPISchemaGenerator(OpenAPISchemaGenerator):
+
+    def get_schema(self, *args, **kwargs):
+        schema = super().get_schema(*args, **kwargs)
+        base_path = getattr(settings, 'CUSTOM_SWAGGER', {})
+        schema.basePath = base_path['BASE_PATH']
+        return schema
